.. _decomposition_ref:

:mod:`nilearn.decomposition`: Multivariate Decompositions
=========================================================

.. automodule:: nilearn.decomposition
   :no-members:
   :no-inherited-members:

Classes
-------

.. currentmodule:: nilearn.decomposition

.. autosummary::
   :toctree: generated/
   :template: class.rst

   CanICA
   DictLearning

.. autoclasstree:: nilearn.decomposition
   :full:
